@@ -11,6 +11,9 @@ class VersionManager(object):
     m_current_version = __version__
     m_version_re = re.compile(r'\((from versions: (.*?))\)')
 
+    def __init__(self, link_pip: bool = False) -> None:
+        self.link_pip = link_pip
+
     def has_updated(self) -> bool:
         return self.m_current_version < self.get_last_version()
 
@@ -27,13 +30,17 @@ class VersionManager(object):
         return last
 
     def start_update(self):
-        import os
-        os.system(
-            f'pip install pdcoder -U ')
+        # import os
+        # os.system(
+        #     f'pip install {self.m_pkg_name} -U ')
+
+        self._use_pip(['install', f'{self.m_pkg_name}', '-U'])
 
     def _use_pip(self, cmds: List[str]):
-        # cmds = ['pip'] + cmds + ['-i', 'https://pypi.douban.com/simple/']
         cmds = ['pip'] + cmds
 
+        if not self.link_pip:
+            cmds = cmds + ['-i', 'https://pypi.douban.com/simple/']
+
         return subprocess.run(cmds,
                               stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)
